Trinarizes a vector of real-valued data using the k-means clustering algorithm. The data is first split into 3 clusters.The values belonging to the cluster with the smallest centroid are set to 0, the values belonging to the greater centroid are set to 1, and the values belonging to the greatest centroid are set to 2.
The number of restarts for k-means. See kmeans for details.
iter.max
The maximum number of iterations for k-means. See kmeans for details.
dip.test
If set to TRUE, Hartigan's dip test for unimodality is performed on vect, and its p-value is returned in the pvalue slot of the result. An insignificant test indicates that the data may not be trinarizeable.
na.rm
If set to TRUE, NA values are removed from the input. Otherwise, trinarization will fail in the presence of NA values.